==> device_frame-0.6.0.tar.gz: lib/src/devices/ios/iphone_13_mini/frame.g.dart <==
// ignore_for_file: require_trailing_commas, non_constant_identifier_names

part of 'device.dart';

// Generated manually with https://fluttershapemaker.com/
class _FramePainter extends CustomPainter {
  const _FramePainter();

  @override
  void paint(Canvas canvas, Size size) {
    Path path_0 = Path();
    path_0.moveTo(864.822, 473.939);
    path_0.lineTo(867.911, 473.939);
    path_0.cubicTo(869.617, 473.939, 871, 475.323, 871, 477.03);
    path_0.lineTo(871, 703.697);
    path_0.cubicTo(871, 705.404, 869.617, 706.788, 867.911, 706.788);
    path_0.lineTo(864.822, 706.788);
    path_0.lineTo(864.822, 473.939);
    path_0.close();

    Paint paint_0_fill = Paint()..style = PaintingStyle.fill;
    paint_0_fill.color = Color(0xff446087).withOpacity(1.0);
    canvas.drawPath(path_0, paint_0_fill);

    Path path_1 = Path();
    path_1.moveTo(6.17773, 754.182);
    path_1.lineTo(3.08907, 754.182);
    path_1.cubicTo(
        1.38325, 754.182, 0.000418235, 752.798, 0.000418385, 751.091);
    path_1.lineTo(0.000430265, 615.091);
    path_1.cubicTo(0.000430415, 613.384, 1.38327, 612, 3.08908, 612);
    path_1.lineTo(6.17775, 612);
    path_1.lineTo(6.17773, 754.182);
    path_1.close();

    Paint paint_1_fill = Paint()..style = PaintingStyle.fill;
    paint_1_fill.color = Color(0xff446087).withOpacity(1.0);
    canvas.drawPath(path_1, paint_1_fill);

    Path path_2 = Path();
    path_2.moveTo(6.17773, 566.667);
    path_2.lineTo(3.08907, 566.667);
    path_2.cubicTo(
        1.38325, 566.667, 0.000418235, 565.283, 0.000418385, 563.576);
    path_2.lineTo(0.000430265, 427.576);
    path_2.cubicTo(0.000430415, 425.869, 1.38327, 424.485, 3.08908, 424.485);
    path_2.lineTo(6.17775, 424.485);
    path_2.lineTo(6.17773, 566.667);
    path_2.close();

    Paint paint_2_fill = Paint()..style = PaintingStyle.fill;
    paint_2_fill.color = Color(0xff446087).withOpacity(1.0);
    canvas.drawPath(path_2, paint_2_fill);

    Path path_3 = Path();
    path_3.moveTo(6.17773, 350.303);
    path_3.lineTo(3.08908, 350.303);
    path_3.cubicTo(
        1.38326, 350.303, 0.000424842, 348.919, 0.000424991, 347.212);
    path_3.lineTo(0.000430571, 283.333);
    path_3.cubicTo(0.000430721, 281.626, 1.38327, 280.242, 3.08908, 280.242);
    path_3.lineTo(6.17774, 280.242);
    path_3.lineTo(6.17773, 350.303);
    path_3.close();

    Paint paint_3_fill = Paint()..style = PaintingStyle.fill;
    paint_3_fill.color = Color(0xff446087).withOpacity(1.0);
    canvas.drawPath(path_3, paint_3_fill);

    Path path_4 = Path();
    path_4.moveTo(6.17773, 187.515);
    path_4.cubicTo(6.17773, 137.655, 6.17773, 112.725, 12.7284, 92.5498);
    path_4.cubicTo(25.9677, 51.7736, 57.9135, 19.8045, 98.66, 6.55546);
    path_4.cubicTo(118.821, 0, 143.733, 0, 193.556, 0);
    path_4.lineTo(677.445, 0);
    path_4.cubicTo(727.268, 0, 752.18, 0, 772.341, 6.55546);
    path_4.cubicTo(813.087, 19.8045, 845.033, 51.7736, 858.272, 92.5498);
    path_4.cubicTo(864.823, 112.725, 864.823, 137.655, 864.823, 187.515);
    path_4.lineTo(864.823, 1580.48);
    path_4.cubicTo(864.823, 1630.34, 864.823, 1655.27, 858.272, 1675.45);
    path_4.cubicTo(845.033, 1716.23, 813.087, 1748.2, 772.341, 1761.44);
    path_4.cubicTo(752.18, 1768, 727.268, 1768, 677.445, 1768);
    path_4.lineTo(193.556, 1768);
    path_4.cubicTo(143.733, 1768, 118.821, 1768, 98.66, 1761.44);
    path_4.cubicTo(57.9135, 1748.2, 25.9677, 1716.23, 12.7284, 1675.45);
    path_4.cubicTo(6.17773, 1655.27, 6.17773, 1630.34, 6.17773, 1580.48);
    path_4.lineTo(6.17773, 187.515);
    path_4.close();

    Paint paint_4_fill = Paint()..style = PaintingStyle.fill;
    paint_4_fill.color = Color(0xff102948).withOpacity(1.0);
    canvas.drawPath(path_4, paint_4_fill);

    Path path_5 = Path();
    path_5.moveTo(678.268, 6.18176);
    path_5.lineTo(192.732, 6.18176);
    path_5.cubicTo(143.354, 6.18176, 119.642, 6.2326, 100.568, 12.4347);
    path_5.cubicTo(61.7025, 25.0722, 31.2312, 55.5658, 18.6029, 94.4601);
    path_5.cubicTo(12.4053, 113.548, 12.3545, 137.277, 12.3545, 186.691);
    path_5.lineTo(12.3545, 1581.31);
    path_5.cubicTo(12.3545, 1630.72, 12.4053, 1654.45, 18.6029, 1673.54);
    path_5.cubicTo(31.2312, 1712.43, 61.7025, 1742.93, 100.568, 1755.57);
    path_5.cubicTo(119.642, 1761.77, 143.354, 1761.82, 192.732, 1761.82);
    path_5.lineTo(678.268, 1761.82);
    path_5.cubicTo(727.645, 1761.82, 751.357, 1761.77, 770.432, 1755.57);
    path_5.cubicTo(809.297, 1742.93, 839.769, 1712.43, 852.397, 1673.54);
    path_5.cubicTo(858.595, 1654.45, 858.645, 1630.72, 858.645, 1581.31);
    path_5.lineTo(858.645, 186.691);
    path_5.cubicTo(858.645, 137.277, 858.595, 113.548, 852.397, 94.4601);
    path_5.cubicTo(839.769, 55.5658, 809.297, 25.0722, 770.432, 12.4347);
    path_5.cubicTo(751.357, 6.2326, 727.645, 6.18176, 678.268, 6.18176);
    path_5.close();
    path_5.moveTo(14.6862, 93.1865);
    path_5.cubicTo(8.23633, 113.052, 8.23633, 137.598, 8.23633, 186.691);
    path_5.lineTo(8.23633, 1581.31);
    path_5.cubicTo(8.23633, 1630.4, 8.23633, 1654.95, 14.6862, 1674.81);
    path_5.cubicTo(27.7219, 1714.96, 59.1762, 1746.44, 99.2958, 1759.48);
    path_5.cubicTo(119.147, 1765.94, 143.675, 1765.94, 192.732, 1765.94);
    path_5.lineTo(678.268, 1765.94);
    path_5.cubicTo(727.325, 1765.94, 751.853, 1765.94, 771.704, 1759.48);
    path_5.cubicTo(811.824, 1746.44, 843.278, 1714.96, 856.314, 1674.81);
    path_5.cubicTo(862.764, 1654.95, 862.764, 1630.4, 862.764, 1581.31);
    path_5.lineTo(862.764, 186.691);
    path_5.cubicTo(862.764, 137.598, 862.764, 113.052, 856.314, 93.1865);
    path_5.cubicTo(843.278, 53.0376, 811.824, 21.5603, 771.704, 8.51515);
    path_5.cubicTo(751.853, 2.06055, 727.325, 2.06055, 678.268, 2.06055);
    path_5.lineTo(192.732, 2.06055);
    path_5.cubicTo(143.675, 2.06055, 119.147, 2.06055, 99.2958, 8.51515);
    path_5.cubicTo(59.1762, 21.5603, 27.7219, 53.0376, 14.6862, 93.1865);
    path_5.close();

    Paint paint_5_fill = Paint()..style = PaintingStyle.fill;
    paint_5_fill.color = Color(0xff446087).withOpacity(1.0);
    canvas.drawPath(path_5, paint_5_fill);

    Path path_6 = Path();
    path_6.moveTo(16.4727, 183.394);
    path_6.cubicTo(16.4727, 137.369, 16.4727, 114.357, 22.5194, 95.7336);
    path_6.cubicTo(34.7404, 58.094, 64.2288, 28.584, 101.841, 16.3542);
    path_6.cubicTo(120.451, 10.303, 143.446, 10.303, 189.437, 10.303);
    path_6.lineTo(681.562, 10.303);
    path_6.cubicTo(727.553, 10.303, 750.549, 10.303, 769.159, 16.3542);
    path_6.cubicTo(806.771, 28.584, 836.259, 58.094, 848.48, 95.7336);
    path_6.cubicTo(854.527, 114.357, 854.527, 137.369, 854.527, 183.394);
    path_6.lineTo(854.527, 1584.61);
    path_6.cubicTo(854.527, 1630.63, 854.527, 1653.64, 848.48, 1672.27);
    path_6.cubicTo(836.259, 1709.91, 806.771, 1739.42, 769.159, 1751.65);
    path_6.cubicTo(750.549, 1757.7, 727.553, 1757.7, 681.562, 1757.7);
    path_6.lineTo(189.437, 1757.7);
    path_6.cubicTo(143.446, 1757.7, 120.451, 1757.7, 101.841, 1751.65);
    path_6.cubicTo(64.2288, 1739.42, 34.7404, 1709.91, 22.5194, 1672.27);
    path_6.cubicTo(16.4727, 1653.64, 16.4727, 1630.63, 16.4727, 1584.61);
    path_6.lineTo(16.4727, 183.394);
    path_6.close();

    Paint paint_6_fill = Paint()..style = PaintingStyle.fill;
    paint_6_fill.color = Color(0xff121515).withOpacity(1.0);
    canvas.drawPath(path_6, paint_6_fill);

    Path path_7 = Path();
    path_7.moveTo(677.445, 0);
    path_7.lineTo(695.977, 0);
    path_7.lineTo(695.977, 10.303);
    path_7.lineTo(677.445, 10.303);
    path_7.lineTo(677.445, 0);
    path_7.close();

    Paint paint_7_fill = Paint()..style = PaintingStyle.fill;
    paint_7_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_7, paint_7_fill);

    Path path_8 = Path();
    path_8.moveTo(854.527, 177.212);
    path_8.lineTo(864.823, 177.212);
    path_8.lineTo(864.823, 195.758);
    path_8.lineTo(854.527, 195.758);
    path_8.lineTo(854.527, 177.212);
    path_8.close();

    Paint paint_8_fill = Paint()..style = PaintingStyle.fill;
    paint_8_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_8, paint_8_fill);

    Path path_9 = Path();
    path_9.moveTo(6.17773, 177.212);
    path_9.lineTo(16.4732, 177.212);
    path_9.lineTo(16.4732, 195.758);
    path_9.lineTo(6.17773, 195.758);
    path_9.lineTo(6.17773, 177.212);
    path_9.close();

    Paint paint_9_fill = Paint()..style = PaintingStyle.fill;
    paint_9_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_9, paint_9_fill);

    Path path_10 = Path();
    path_10.moveTo(6.17773, 1572.24);
    path_10.lineTo(16.4732, 1572.24);
    path_10.lineTo(16.4732, 1590.79);
    path_10.lineTo(6.17773, 1590.79);
    path_10.lineTo(6.17773, 1572.24);
    path_10.close();

    Paint paint_10_fill = Paint()..style = PaintingStyle.fill;
    paint_10_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_10, paint_10_fill);

    Path path_11 = Path();
    path_11.moveTo(854.527, 1572.24);
    path_11.lineTo(864.823, 1572.24);
    path_11.lineTo(864.823, 1590.79);
    path_11.lineTo(854.527, 1590.79);
    path_11.lineTo(854.527, 1572.24);
    path_11.close();

    Paint paint_11_fill = Paint()..style = PaintingStyle.fill;
    paint_11_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_11, paint_11_fill);

    Path path_12 = Path();
    path_12.moveTo(175.024, 1757.7);
    path_12.lineTo(193.556, 1757.7);
    path_12.lineTo(193.556, 1768);
    path_12.lineTo(175.024, 1768);
    path_12.lineTo(175.024, 1757.7);
    path_12.close();

    Paint paint_12_fill = Paint()..style = PaintingStyle.fill;
    paint_12_fill.color = Color(0xff48627E).withOpacity(1.0);
    canvas.drawPath(path_12, paint_12_fill);

    Path path_13 = Path();
    path_13.moveTo(304.473, 85.9697);
    path_13.cubicTo(313.57, 85.9697, 320.946, 78.5892, 320.946, 69.4848);
    path_13.cubicTo(320.946, 60.3805, 313.57, 53, 304.473, 53);
    path_13.cubicTo(295.375, 53, 288, 60.3805, 288, 69.4848);
    path_13.cubicTo(288, 78.5892, 295.375, 85.9697, 304.473, 85.9697);
    path_13.close();

    Paint paint_13_fill = Paint()..style = PaintingStyle.fill;
    paint_13_fill.color = Color(0xff262C2D).withOpacity(1.0);
    canvas.drawPath(path_13, paint_13_fill);

    Path path_14 = Path();
    path_14.moveTo(304.473, 79.7879);
    path_14.cubicTo(310.159, 79.7879, 314.769, 75.1751, 314.769, 69.4849);
    path_14.cubicTo(314.769, 63.7947, 310.159, 59.1819, 304.473, 59.1819);
    path_14.cubicTo(298.787, 59.1819, 294.178, 63.7947, 294.178, 69.4849);
    path_14.cubicTo(294.178, 75.1751, 298.787, 79.7879, 304.473, 79.7879);
    path_14.close();

    Paint paint_14_fill = Paint()..style = PaintingStyle.fill;
    paint_14_fill.color = Color(0xff121515).withOpacity(1.0);
    canvas.drawPath(path_14, paint_14_fill);

    Path path_15 = Path();
    path_15.moveTo(304.473, 67.4242);
    path_15.cubicTo(305.61, 67.4242, 306.532, 66.5016, 306.532, 65.3636);
    path_15.cubicTo(306.532, 64.2255, 305.61, 63.303, 304.473, 63.303);
    path_15.cubicTo(303.336, 63.303, 302.414, 64.2255, 302.414, 65.3636);
    path_15.cubicTo(302.414, 66.5016, 303.336, 67.4242, 304.473, 67.4242);
    path_15.close();

    Paint paint_15_fill = Paint()..style = PaintingStyle.fill;
    paint_15_fill.color = Color(0xff636F73).withOpacity(1.0);
    canvas.drawPath(path_15, paint_15_fill);

    Path path_16 = Path();
    path_16.moveTo(361, 10);
    path_16.lineTo(510, 10);
    path_16.lineTo(510, 14);
    path_16.cubicTo(510, 18.4183, 506.418, 22, 502, 22);
    path_16.lineTo(369, 22);
    path_16.cubicTo(364.582, 22, 361, 18.4183, 361, 14);
    path_16.lineTo(361, 10);
    path_16.close();

    Paint paint_16_fill = Paint()..style = PaintingStyle.fill;
    paint_16_fill.color = Color(0xff262C2D).withOpacity(1.0);
    canvas.drawPath(path_16, paint_16_fill);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return false;
  }
}

==> device_frame-1.1.0.tar.gz: lib/src/devices/ios/iphone_13_mini/frame.g.dart <==
// ignore_for_file: require_trailing_commas, non_constant_identifier_names

part of 'device.dart';

// Generated manually with https://fluttershapemaker.com/
class _FramePainter extends CustomPainter {
  const _FramePainter();

  @override
  void paint(Canvas canvas, Size size) {
    final path_0 = Path();
    path_0.moveTo(864.822, 473.939);
    path_0.lineTo(867.911, 473.939);
    path_0.cubicTo(869.617, 473.939, 871, 475.323, 871, 477.03);
    path_0.lineTo(871, 703.697);
    path_0.cubicTo(871, 705.404, 869.617, 706.788, 867.911, 706.788);
    path_0.lineTo(864.822, 706.788);
    path_0.lineTo(864.822, 473.939);
    path_0.close();

    final paint_0_fill = Paint()..style = PaintingStyle.fill;
    paint_0_fill.color = const Color(0xff446087);
    canvas.drawPath(path_0, paint_0_fill);

    final path_1 = Path();
    path_1.moveTo(6.17773, 754.182);
    path_1.lineTo(3.08907, 754.182);
    path_1.cubicTo(
        1.38325, 754.182, 0.000418235, 752.798, 0.000418385, 751.091);
    path_1.lineTo(0.000430265, 615.091);
    path_1.cubicTo(0.000430415, 613.384, 1.38327, 612, 3.08908, 612);
    path_1.lineTo(6.17775, 612);
    path_1.lineTo(6.17773, 754.182);
    path_1.close();

    final paint_1_fill = Paint()..style = PaintingStyle.fill;
    paint_1_fill.color = const Color(0xff446087);
    canvas.drawPath(path_1, paint_1_fill);

    final path_2 = Path();
    path_2.moveTo(6.17773, 566.667);
    path_2.lineTo(3.08907, 566.667);
    path_2.cubicTo(
        1.38325, 566.667, 0.000418235, 565.283, 0.000418385, 563.576);
    path_2.lineTo(0.000430265, 427.576);
    path_2.cubicTo(0.000430415, 425.869, 1.38327, 424.485, 3.08908, 424.485);
    path_2.lineTo(6.17775, 424.485);
    path_2.lineTo(6.17773, 566.667);
    path_2.close();

    final paint_2_fill = Paint()..style = PaintingStyle.fill;
    paint_2_fill.color = const Color(0xff446087);
    canvas.drawPath(path_2, paint_2_fill);

    final path_3 = Path();
    path_3.moveTo(6.17773, 350.303);
    path_3.lineTo(3.08908, 350.303);
    path_3.cubicTo(
        1.38326, 350.303, 0.000424842, 348.919, 0.000424991, 347.212);
    path_3.lineTo(0.000430571, 283.333);
    path_3.cubicTo(0.000430721, 281.626, 1.38327, 280.242, 3.08908, 280.242);
    path_3.lineTo(6.17774, 280.242);
    path_3.lineTo(6.17773, 350.303);
    path_3.close();

    final paint_3_fill = Paint()..style = PaintingStyle.fill;
    paint_3_fill.color = const Color(0xff446087);
    canvas.drawPath(path_3, paint_3_fill);

    final path_4 = Path();
    path_4.moveTo(6.17773, 187.515);
    path_4.cubicTo(6.17773, 137.655, 6.17773, 112.725, 12.7284, 92.5498);
    path_4.cubicTo(25.9677, 51.7736, 57.9135, 19.8045, 98.66, 6.55546);
    path_4.cubicTo(118.821, 0, 143.733, 0, 193.556, 0);
    path_4.lineTo(677.445, 0);
    path_4.cubicTo(727.268, 0, 752.18, 0, 772.341, 6.55546);
    path_4.cubicTo(813.087, 19.8045, 845.033, 51.7736, 858.272, 92.5498);
    path_4.cubicTo(864.823, 112.725, 864.823, 137.655, 864.823, 187.515);
    path_4.lineTo(864.823, 1580.48);
    path_4.cubicTo(864.823, 1630.34, 864.823, 1655.27, 858.272, 1675.45);
    path_4.cubicTo(845.033, 1716.23, 813.087, 1748.2, 772.341, 1761.44);
    path_4.cubicTo(752.18, 1768, 727.268, 1768, 677.445, 1768);
    path_4.lineTo(193.556, 1768);
    path_4.cubicTo(143.733, 1768, 118.821, 1768, 98.66, 1761.44);
    path_4.cubicTo(57.9135, 1748.2, 25.9677, 1716.23, 12.7284, 1675.45);
    path_4.cubicTo(6.17773, 1655.27, 6.17773, 1630.34, 6.17773, 1580.48);
    path_4.lineTo(6.17773, 187.515);
    path_4.close();

    final paint_4_fill = Paint()..style = PaintingStyle.fill;
    paint_4_fill.color = const Color(0xff102948);
    canvas.drawPath(path_4, paint_4_fill);

    final path_5 = Path();
    path_5.moveTo(678.268, 6.18176);
    path_5.lineTo(192.732, 6.18176);
    path_5.cubicTo(143.354, 6.18176, 119.642, 6.2326, 100.568, 12.4347);
    path_5.cubicTo(61.7025, 25.0722, 31.2312, 55.5658, 18.6029, 94.4601);
    path_5.cubicTo(12.4053, 113.548, 12.3545, 137.277, 12.3545, 186.691);
    path_5.lineTo(12.3545, 1581.31);
    path_5.cubicTo(12.3545, 1630.72, 12.4053, 1654.45, 18.6029, 1673.54);
    path_5.cubicTo(31.2312, 1712.43, 61.7025, 1742.93, 100.568, 1755.57);
    path_5.cubicTo(119.642, 1761.77, 143.354, 1761.82, 192.732, 1761.82);
    path_5.lineTo(678.268, 1761.82);
    path_5.cubicTo(727.645, 1761.82, 751.357, 1761.77, 770.432, 1755.57);
    path_5.cubicTo(809.297, 1742.93, 839.769, 1712.43, 852.397, 1673.54);
    path_5.cubicTo(858.595, 1654.45, 858.645, 1630.72, 858.645, 1581.31);
    path_5.lineTo(858.645, 186.691);
    path_5.cubicTo(858.645, 137.277, 858.595, 113.548, 852.397, 94.4601);
    path_5.cubicTo(839.769, 55.5658, 809.297, 25.0722, 770.432, 12.4347);
    path_5.cubicTo(751.357, 6.2326, 727.645, 6.18176, 678.268, 6.18176);
    path_5.close();
    path_5.moveTo(14.6862, 93.1865);
    path_5.cubicTo(8.23633, 113.052, 8.23633, 137.598, 8.23633, 186.691);
    path_5.lineTo(8.23633, 1581.31);
    path_5.cubicTo(8.23633, 1630.4, 8.23633, 1654.95, 14.6862, 1674.81);
    path_5.cubicTo(27.7219, 1714.96, 59.1762, 1746.44, 99.2958, 1759.48);
    path_5.cubicTo(119.147, 1765.94, 143.675, 1765.94, 192.732, 1765.94);
    path_5.lineTo(678.268, 1765.94);
    path_5.cubicTo(727.325, 1765.94, 751.853, 1765.94, 771.704, 1759.48);
    path_5.cubicTo(811.824, 1746.44, 843.278, 1714.96, 856.314, 1674.81);
    path_5.cubicTo(862.764, 1654.95, 862.764, 1630.4, 862.764, 1581.31);
    path_5.lineTo(862.764, 186.691);
    path_5.cubicTo(862.764, 137.598, 862.764, 113.052, 856.314, 93.1865);
    path_5.cubicTo(843.278, 53.0376, 811.824, 21.5603, 771.704, 8.51515);
    path_5.cubicTo(751.853, 2.06055, 727.325, 2.06055, 678.268, 2.06055);
    path_5.lineTo(192.732, 2.06055);
    path_5.cubicTo(143.675, 2.06055, 119.147, 2.06055, 99.2958, 8.51515);
    path_5.cubicTo(59.1762, 21.5603, 27.7219, 53.0376, 14.6862, 93.1865);
    path_5.close();

    final paint_5_fill = Paint()..style = PaintingStyle.fill;
    paint_5_fill.color = const Color(0xff446087);
    canvas.drawPath(path_5, paint_5_fill);

    final path_6 = Path();
    path_6.moveTo(16.4727, 183.394);
    path_6.cubicTo(16.4727, 137.369, 16.4727, 114.357, 22.5194, 95.7336);
    path_6.cubicTo(34.7404, 58.094, 64.2288, 28.584, 101.841, 16.3542);
    path_6.cubicTo(120.451, 10.303, 143.446, 10.303, 189.437, 10.303);
    path_6.lineTo(681.562, 10.303);
    path_6.cubicTo(727.553, 10.303, 750.549, 10.303, 769.159, 16.3542);
    path_6.cubicTo(806.771, 28.584, 836.259, 58.094, 848.48, 95.7336);
    path_6.cubicTo(854.527, 114.357, 854.527, 137.369, 854.527, 183.394);
    path_6.lineTo(854.527, 1584.61);
    path_6.cubicTo(854.527, 1630.63, 854.527, 1653.64, 848.48, 1672.27);
    path_6.cubicTo(836.259, 1709.91, 806.771, 1739.42, 769.159, 1751.65);
    path_6.cubicTo(750.549, 1757.7, 727.553, 1757.7, 681.562, 1757.7);
    path_6.lineTo(189.437, 1757.7);
    path_6.cubicTo(143.446, 1757.7, 120.451, 1757.7, 101.841, 1751.65);
    path_6.cubicTo(64.2288, 1739.42, 34.7404, 1709.91, 22.5194, 1672.27);
    path_6.cubicTo(16.4727, 1653.64, 16.4727, 1630.63, 16.4727, 1584.61);
    path_6.lineTo(16.4727, 183.394);
    path_6.close();

    final paint_6_fill = Paint()..style = PaintingStyle.fill;
    paint_6_fill.color = const Color(0xff121515);
    canvas.drawPath(path_6, paint_6_fill);

    final path_7 = Path();
    path_7.moveTo(677.445, 0);
    path_7.lineTo(695.977, 0);
    path_7.lineTo(695.977, 10.303);
    path_7.lineTo(677.445, 10.303);
    path_7.lineTo(677.445, 0);
    path_7.close();

    final paint_7_fill = Paint()..style = PaintingStyle.fill;
    paint_7_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_7, paint_7_fill);

    final path_8 = Path();
    path_8.moveTo(854.527, 177.212);
    path_8.lineTo(864.823, 177.212);
    path_8.lineTo(864.823, 195.758);
    path_8.lineTo(854.527, 195.758);
    path_8.lineTo(854.527, 177.212);
    path_8.close();

    final paint_8_fill = Paint()..style = PaintingStyle.fill;
    paint_8_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_8, paint_8_fill);

    final path_9 = Path();
    path_9.moveTo(6.17773, 177.212);
    path_9.lineTo(16.4732, 177.212);
    path_9.lineTo(16.4732, 195.758);
    path_9.lineTo(6.17773, 195.758);
    path_9.lineTo(6.17773, 177.212);
    path_9.close();

    final paint_9_fill = Paint()..style = PaintingStyle.fill;
    paint_9_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_9, paint_9_fill);

    final path_10 = Path();
    path_10.moveTo(6.17773, 1572.24);
    path_10.lineTo(16.4732, 1572.24);
    path_10.lineTo(16.4732, 1590.79);
    path_10.lineTo(6.17773, 1590.79);
    path_10.lineTo(6.17773, 1572.24);
    path_10.close();

    final paint_10_fill = Paint()..style = PaintingStyle.fill;
    paint_10_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_10, paint_10_fill);

    final path_11 = Path();
    path_11.moveTo(854.527, 1572.24);
    path_11.lineTo(864.823, 1572.24);
    path_11.lineTo(864.823, 1590.79);
    path_11.lineTo(854.527, 1590.79);
    path_11.lineTo(854.527, 1572.24);
    path_11.close();

    final paint_11_fill = Paint()..style = PaintingStyle.fill;
    paint_11_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_11, paint_11_fill);

    final path_12 = Path();
    path_12.moveTo(175.024, 1757.7);
    path_12.lineTo(193.556, 1757.7);
    path_12.lineTo(193.556, 1768);
    path_12.lineTo(175.024, 1768);
    path_12.lineTo(175.024, 1757.7);
    path_12.close();

    final paint_12_fill = Paint()..style = PaintingStyle.fill;
    paint_12_fill.color = const Color(0xff48627E);
    canvas.drawPath(path_12, paint_12_fill);

    final path_13 = Path();
    path_13.moveTo(304.473, 85.9697);
    path_13.cubicTo(313.57, 85.9697, 320.946, 78.5892, 320.946, 69.4848);
    path_13.cubicTo(320.946, 60.3805, 313.57, 53, 304.473, 53);
    path_13.cubicTo(295.375, 53, 288, 60.3805, 288, 69.4848);
    path_13.cubicTo(288, 78.5892, 295.375, 85.9697, 304.473, 85.9697);
    path_13.close();

    final paint_13_fill = Paint()..style = PaintingStyle.fill;
    paint_13_fill.color = const Color(0xff262C2D);
    canvas.drawPath(path_13, paint_13_fill);

    final path_14 = Path();
    path_14.moveTo(304.473, 79.7879);
    path_14.cubicTo(310.159, 79.7879, 314.769, 75.1751, 314.769, 69.4849);
    path_14.cubicTo(314.769, 63.7947, 310.159, 59.1819, 304.473, 59.1819);
    path_14.cubicTo(298.787, 59.1819, 294.178, 63.7947, 294.178, 69.4849);
    path_14.cubicTo(294.178, 75.1751, 298.787, 79.7879, 304.473, 79.7879);
    path_14.close();

    final paint_14_fill = Paint()..style = PaintingStyle.fill;
    paint_14_fill.color = const Color(0xff121515);
    canvas.drawPath(path_14, paint_14_fill);

    final path_15 = Path();
    path_15.moveTo(304.473, 67.4242);
    path_15.cubicTo(305.61, 67.4242, 306.532, 66.5016, 306.532, 65.3636);
    path_15.cubicTo(306.532, 64.2255, 305.61, 63.303, 304.473, 63.303);
    path_15.cubicTo(303.336, 63.303, 302.414, 64.2255, 302.414, 65.3636);
    path_15.cubicTo(302.414, 66.5016, 303.336, 67.4242, 304.473, 67.4242);
    path_15.close();

    final paint_15_fill = Paint()..style = PaintingStyle.fill;
    paint_15_fill.color = const Color(0xff636F73);
    canvas.drawPath(path_15, paint_15_fill);

    final path_16 = Path();
    path_16.moveTo(361, 10);
    path_16.lineTo(510, 10);
    path_16.lineTo(510, 14);
    path_16.cubicTo(510, 18.4183, 506.418, 22, 502, 22);
    path_16.lineTo(369, 22);
    path_16.cubicTo(364.582, 22, 361, 18.4183, 361, 14);
    path_16.lineTo(361, 10);
    path_16.close();

    final paint_16_fill = Paint()..style = PaintingStyle.fill;
    paint_16_fill.color = const Color(0xff262C2D);
    canvas.drawPath(path_16, paint_16_fill);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return false;
  }
}
